#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-CwpMQbLvYIwK8GdI0h2opF
key:                  nanospec-0.2.2-CwpMQbLvYIwK8GdI0h2opF
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  6cbac4cbc8d0d367097246efed3f057a
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-CwpMQbLvYIwK8GdI0h2opF
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

